==> digiKam-8.1.0.tar.xz: digikam-8.1.0/core/dplugins/generic/tools/panorama/wizard/panopreviewpage.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2011-05-23
 * Description : a tool to create panorama by fusion of several images.
 *
 * SPDX-FileCopyrightText: 2011-2016 by Benjamin Girault <benjamin dot girault at gmail dot com>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * ============================================================ */

#ifndef DIGIKAM_PANO_PREVIEW_PAGE_H
#define DIGIKAM_PANO_PREVIEW_PAGE_H

// Local includes

#include "dwizardpage.h"
#include "panoactions.h"
#include <QMutexLocker>
#include <QMutex>

using namespace Digikam;

namespace DigikamGenericPanoramaPlugin
{

class PanoManager;

class PanoPreviewPage : public DWizardPage
{
    Q_OBJECT

public:

    explicit PanoPreviewPage(PanoManager* const mngr, QWizard* const dlg);
    ~PanoPreviewPage() override;

private:

    void computePreview();
    void startStitching();

    void preInitializePage();
    void initializePage()   override;
    bool validatePage()     override;
    void cleanupPage()      override;

#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
    void cleanupPage(QMutexLocker<QMutex>& lock);
#else
    void cleanupPage(QMutexLocker& lock);
#endif

Q_SIGNALS:

    void signalPreviewFinished();
    void signalStitchingFinished();

private Q_SLOTS:

    void slotCancel();
    void slotStartStitching();
    void slotPanoAction(const DigikamGenericPanoramaPlugin::PanoActionData&);

private:

    class Private;
    Private* const d;
};

} // namespace DigikamGenericPanoramaPlugin

#endif // DIGIKAM_PANO_PREVIEW_PAGE_H

==> digiKam-8.3.0-1.tar.xz: digikam-8.3.0/core/dplugins/generic/tools/panorama/wizard/panopreviewpage.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2011-05-23
 * Description : a tool to create panorama by fusion of several images.
 *
 * SPDX-FileCopyrightText: 2011-2016 by Benjamin Girault <benjamin dot girault at gmail dot com>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * ============================================================ */

#ifndef DIGIKAM_PANO_PREVIEW_PAGE_H
#define DIGIKAM_PANO_PREVIEW_PAGE_H

// Local includes

#include "dwizardpage.h"
#include "panoactions.h"
#include <QMutexLocker>
#include <QMutex>

using namespace Digikam;

namespace DigikamGenericPanoramaPlugin
{

class PanoManager;

class PanoPreviewPage : public DWizardPage
{
    Q_OBJECT

public:

    explicit PanoPreviewPage(PanoManager* const mngr, QWizard* const dlg);
    ~PanoPreviewPage() override;

private:

    void computePreview();
    void startStitching();

    void preInitializePage();
    void initializePage()   override;
    bool validatePage()     override;
    void cleanupPage()      override;

#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))

    void cleanupPage(QMutexLocker<QMutex>& lock);

#else

    void cleanupPage(QMutexLocker& lock);

#endif

Q_SIGNALS:

    void signalPreviewFinished();
    void signalStitchingFinished();

private Q_SLOTS:

    void slotCancel();
    void slotStartStitching();
    void slotPanoAction(const DigikamGenericPanoramaPlugin::PanoActionData&);

private:

    class Private;
    Private* const d;
};

} // namespace DigikamGenericPanoramaPlugin

#endif // DIGIKAM_PANO_PREVIEW_PAGE_H
